==> jaysonic-3.1.1.tgz: package/lib/server/protocol/ws.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcServerProtocol = require("./base");
/**
 * Creates instance of WsServerProtocol
 * @extends JsonRpcServerProtocol
 */


var WsServerProtocol = /*#__PURE__*/function (_JsonRpcServerProtoco) {
  _inherits(WsServerProtocol, _JsonRpcServerProtoco);

  var _super = _createSuper(WsServerProtocol);

  /**
   * In addition to the params and properties for [JsonRpcServerProtocol]{@link JsonRpcServerProtocol}
   * the WsServerProtocol has the following properties:
   *
   * @property {string} event HTTP response object
   * @property {object} client.write  Overrides `client.write` method to use `client.send` for Websocket
   */
  function WsServerProtocol(factory, client, version, delimiter) {
    var _this;

    _classCallCheck(this, WsServerProtocol);

    _this = _super.call(this, factory, client, version, delimiter);
    _this.event = "message"; // ws uses 'message', tcp uses 'data'

    _this.client.write = _this.client.send; // ws uses .send(), tcp uses .write()

    return _this;
  }

  return WsServerProtocol;
}(JsonRpcServerProtocol);

module.exports = WsServerProtocol;

==> jaysonic-3.5.1.tgz: package/lib/server/protocol/ws.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var JsonRpcServerProtocol = require("./base");
/**
 * Creates instance of WsServerProtocol
 * @extends JsonRpcServerProtocol
 */


var WsServerProtocol = /*#__PURE__*/function (_JsonRpcServerProtoco) {
  _inherits(WsServerProtocol, _JsonRpcServerProtoco);

  var _super = _createSuper(WsServerProtocol);

  /**
   * In addition to the params and properties for [JsonRpcServerProtocol]{@link JsonRpcServerProtocol}
   * the WsServerProtocol has the following properties:
   *
   * @property {string} event HTTP response object
   * @property {object} client.write  Overrides `client.write` method to use `client.send` for Websocket
   */
  function WsServerProtocol(factory, client, version, delimiter) {
    var _this;

    _classCallCheck(this, WsServerProtocol);

    _this = _super.call(this, factory, client, version, delimiter);
    _this.event = "message"; // ws uses 'message', tcp uses 'data'

    _this.client.write = _this.client.send; // ws uses .send(), tcp uses .write()

    return _this;
  }

  return WsServerProtocol;
}(JsonRpcServerProtocol);

module.exports = WsServerProtocol;
